==> jc-1.4.0.tar.gz: soot/jimple/NullConstant.h <==
// public class soot.jimple.NullConstant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class 8a1af2f5d59b712f soot_jimple_NullConstant

// header file dependencies
// @dep_header soot_jimple_Constant

#include "soot/jimple/Constant.h"

#ifndef _JC_soot_jimple_NullConstant_H_
#define _JC_soot_jimple_NullConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_NullConstant$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_NullConstant$sub_refs	_jc_soot_jimple_NullConstant$sub_refs;
typedef struct _jc_soot_jimple_NullConstant$sub_nonrefs	_jc_soot_jimple_NullConstant$sub_nonrefs;
typedef struct _jc_soot_jimple_NullConstant$refs	_jc_soot_jimple_NullConstant$refs;
typedef struct _jc_soot_jimple_NullConstant$nonrefs	_jc_soot_jimple_NullConstant$nonrefs;
typedef struct _jc_soot_jimple_NullConstant$object	_jc_soot_jimple_NullConstant$object;

typedef const struct _jc_soot_jimple_NullConstant$vmethods	_jc_soot_jimple_NullConstant$vmethods;
typedef const struct _jc_soot_jimple_NullConstant$vtable	_jc_soot_jimple_NullConstant$vtable;
typedef const struct _jc_soot_jimple_NullConstant$vtype	_jc_soot_jimple_NullConstant$vtype;

// Constructors
extern void _jc_soot_jimple_NullConstant$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_NullConstant$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_NullConstant$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_NullConstant$object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_NullConstant$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_NullConstant$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_soot_Type$object *_jc_soot_jimple_NullConstant$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_NullConstant$object *);
extern jint _jc_soot_jimple_NullConstant$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_NullConstant$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_NullConstant$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_NullConstant$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_NullConstant$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_NullConstant$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_NullConstant$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_jimple_NullConstant$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_NullConstant$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_jimple_NullConstant$object *_jc_soot_jimple_NullConstant$method$v$77fd47d443504375(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_NullConstant$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_NullConstant$object *, struct _jc_object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_NullConstant$object *, struct _jc_java_lang_Object$object *);
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_NullConstant$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_NullConstant$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_NullConstant$object *);
};

// Vtable
struct _jc_soot_jimple_NullConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_jimple_NullConstant$vmethods	soot_jimple_NullConstant;
};

// Vtype
struct _jc_soot_jimple_NullConstant$vtype {
	_jc_type			type;
	_jc_soot_jimple_NullConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_NullConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_NullConstant$refs {
    _jc_soot_jimple_NullConstant$sub_refs	soot_jimple_NullConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_NullConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_NullConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_jimple_NullConstant$sub_nonrefs	soot_jimple_NullConstant;
};

// Object instance structure
struct _jc_soot_jimple_NullConstant$object {
	_jc_soot_jimple_NullConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_NullConstant$vtype	*vtype;
	_jc_soot_jimple_NullConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_NullConstant$vtype _jc_soot_jimple_NullConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_NullConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_NullConstant$class_object;

#endif	/* _JC_soot_jimple_NullConstant_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/NullConstant.h <==
// public class soot.jimple.NullConstant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class 8a1af2f5d59b712f soot_jimple_NullConstant

// header file dependencies
// @dep_header soot_jimple_Constant

#include "soot/jimple/Constant.h"

#ifndef _JC_soot_jimple_NullConstant_H_
#define _JC_soot_jimple_NullConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_NullConstant$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_NullConstant$sub_refs	_jc_soot_jimple_NullConstant$sub_refs;
typedef struct _jc_soot_jimple_NullConstant$sub_nonrefs	_jc_soot_jimple_NullConstant$sub_nonrefs;
typedef struct _jc_soot_jimple_NullConstant$refs	_jc_soot_jimple_NullConstant$refs;
typedef struct _jc_soot_jimple_NullConstant$nonrefs	_jc_soot_jimple_NullConstant$nonrefs;
typedef struct _jc_soot_jimple_NullConstant$object	_jc_soot_jimple_NullConstant$object;

typedef const struct _jc_soot_jimple_NullConstant$vmethods	_jc_soot_jimple_NullConstant$vmethods;
typedef const struct _jc_soot_jimple_NullConstant$vtable	_jc_soot_jimple_NullConstant$vtable;
typedef const struct _jc_soot_jimple_NullConstant$vtype	_jc_soot_jimple_NullConstant$vtype;

// Constructors
extern void _jc_soot_jimple_NullConstant$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_NullConstant$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_NullConstant$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_NullConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_NullConstant$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_NullConstant$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_jimple_NullConstant$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_NullConstant$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_NullConstant$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_NullConstant$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_NullConstant$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_NullConstant$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_NullConstant$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_NullConstant$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_NullConstant$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_jimple_NullConstant$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_NullConstant$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_jimple_NullConstant$object *_jc_soot_jimple_NullConstant$method$v$77fd47d443504375(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_NullConstant$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_NullConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_NullConstant$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_NullConstant$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_NullConstant$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_NullConstant$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_NullConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_jimple_NullConstant$vmethods	soot_jimple_NullConstant;
};

// Vtype
struct _jc_soot_jimple_NullConstant$vtype {
	_jc_type			type;
	_jc_soot_jimple_NullConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_NullConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_NullConstant$refs {
    _jc_soot_jimple_NullConstant$sub_refs	soot_jimple_NullConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_NullConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_NullConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_jimple_NullConstant$sub_nonrefs	soot_jimple_NullConstant;
};

// Object instance structure
struct _jc_soot_jimple_NullConstant$object {
	_jc_soot_jimple_NullConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_NullConstant$vtype	*vtype;
	_jc_soot_jimple_NullConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_NullConstant$vtype _jc_soot_jimple_NullConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_NullConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_NullConstant$class_object;

#endif	/* _JC_soot_jimple_NullConstant_H_ */
